==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/PerClientRateLimitSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PerClientRateLimitMode;
import com.okta.sdk.resource.model.PerClientRateLimitSettingsUseCaseModeOverrides;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ PerClientRateLimitSettings.JSON_PROPERTY_DEFAULT_MODE,
        PerClientRateLimitSettings.JSON_PROPERTY_USE_CASE_MODE_OVERRIDES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class PerClientRateLimitSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DEFAULT_MODE = "defaultMode";
    private PerClientRateLimitMode defaultMode;

    public static final String JSON_PROPERTY_USE_CASE_MODE_OVERRIDES = "useCaseModeOverrides";
    private PerClientRateLimitSettingsUseCaseModeOverrides useCaseModeOverrides;

    public PerClientRateLimitSettings() {
    }

    public PerClientRateLimitSettings defaultMode(PerClientRateLimitMode defaultMode) {

        this.defaultMode = defaultMode;
        return this;
    }

    /**
     * Get defaultMode
     *
     * @return defaultMode
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_MODE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public PerClientRateLimitMode getDefaultMode() {
        return defaultMode;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT_MODE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setDefaultMode(PerClientRateLimitMode defaultMode) {
        this.defaultMode = defaultMode;
    }

    public PerClientRateLimitSettings useCaseModeOverrides(
            PerClientRateLimitSettingsUseCaseModeOverrides useCaseModeOverrides) {

        this.useCaseModeOverrides = useCaseModeOverrides;
        return this;
    }

    /**
     * Get useCaseModeOverrides
     *
     * @return useCaseModeOverrides
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USE_CASE_MODE_OVERRIDES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PerClientRateLimitSettingsUseCaseModeOverrides getUseCaseModeOverrides() {
        return useCaseModeOverrides;
    }

    @JsonProperty(JSON_PROPERTY_USE_CASE_MODE_OVERRIDES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUseCaseModeOverrides(PerClientRateLimitSettingsUseCaseModeOverrides useCaseModeOverrides) {
        this.useCaseModeOverrides = useCaseModeOverrides;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PerClientRateLimitSettings perClientRateLimitSettings = (PerClientRateLimitSettings) o;
        return Objects.equals(this.defaultMode, perClientRateLimitSettings.defaultMode)
                && Objects.equals(this.useCaseModeOverrides, perClientRateLimitSettings.useCaseModeOverrides);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(defaultMode, useCaseModeOverrides);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PerClientRateLimitSettings {\n");
        sb.append("    defaultMode: ").append(toIndentedString(defaultMode)).append("\n");
        sb.append("    useCaseModeOverrides: ").append(toIndentedString(useCaseModeOverrides)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PerClientRateLimitSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PerClientRateLimitMode;
import com.okta.sdk.resource.model.PerClientRateLimitSettingsUseCaseModeOverrides;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ PerClientRateLimitSettings.JSON_PROPERTY_DEFAULT_MODE,
        PerClientRateLimitSettings.JSON_PROPERTY_USE_CASE_MODE_OVERRIDES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PerClientRateLimitSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DEFAULT_MODE = "defaultMode";
    private PerClientRateLimitMode defaultMode;

    public static final String JSON_PROPERTY_USE_CASE_MODE_OVERRIDES = "useCaseModeOverrides";
    private PerClientRateLimitSettingsUseCaseModeOverrides useCaseModeOverrides;

    public PerClientRateLimitSettings() {
    }

    public PerClientRateLimitSettings defaultMode(PerClientRateLimitMode defaultMode) {

        this.defaultMode = defaultMode;
        return this;
    }

    /**
     * Get defaultMode
     *
     * @return defaultMode
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_MODE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public PerClientRateLimitMode getDefaultMode() {
        return defaultMode;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT_MODE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setDefaultMode(PerClientRateLimitMode defaultMode) {
        this.defaultMode = defaultMode;
    }

    public PerClientRateLimitSettings useCaseModeOverrides(
            PerClientRateLimitSettingsUseCaseModeOverrides useCaseModeOverrides) {

        this.useCaseModeOverrides = useCaseModeOverrides;
        return this;
    }

    /**
     * Get useCaseModeOverrides
     *
     * @return useCaseModeOverrides
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USE_CASE_MODE_OVERRIDES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PerClientRateLimitSettingsUseCaseModeOverrides getUseCaseModeOverrides() {
        return useCaseModeOverrides;
    }

    @JsonProperty(JSON_PROPERTY_USE_CASE_MODE_OVERRIDES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUseCaseModeOverrides(PerClientRateLimitSettingsUseCaseModeOverrides useCaseModeOverrides) {
        this.useCaseModeOverrides = useCaseModeOverrides;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PerClientRateLimitSettings perClientRateLimitSettings = (PerClientRateLimitSettings) o;
        return Objects.equals(this.defaultMode, perClientRateLimitSettings.defaultMode)
                && Objects.equals(this.useCaseModeOverrides, perClientRateLimitSettings.useCaseModeOverrides);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(defaultMode, useCaseModeOverrides);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PerClientRateLimitSettings {\n");
        sb.append("    defaultMode: ").append(toIndentedString(defaultMode)).append("\n");
        sb.append("    useCaseModeOverrides: ").append(toIndentedString(useCaseModeOverrides)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
